# Pwatch

A simple python tool to log process with excessive resource usage

## Install

```console
pip install pwatch
```

## Usage

By default pwatch will set limits to 0, that means every process will be reported.

For more informations:

```console
pwatch --help
```

## Used libraries

This software relies on the great psutil python library.
